# Generated by Django 2.2.2 on 2019-06-11 10:51

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='CrawlerNode',
            fields=[
                ('id', models.AutoField(primary_key=True, serialize=False)),
                ('name', models.CharField(max_length=255)),
                ('host', models.CharField(default='127.0.0.1', max_length=255)),
                ('port', models.CharField(default=6800, max_length=255)),
            ],
        ),
    ]
